@@ -1,6 +1,6 @@
 """
 :author: Parliskaya
-:license: Apache License, Version 2.0, see LICENSE file
+:license: MIT License, see LICENSE file
 
 :copyright: (c) 2022 Parliskaya
 """
@@ -15,17 +15,7 @@ from .users import users
 from .news_feed import news_feed
 from .wall import wall
 
-openvkapi = openvkapi()
-account = account()
-friends = friends()
-groups = groups()
-messages = messages()
-utils = utils()
-users = users()
-news_feed = news_feed()
-wall = wall()
-
 
 __author__ = 'Parliskaya'
-__version__ = '0.0.3'
+__version__ = '0.0.6'
 __email__ = 'alonaparlis@gmail.com'
\ No newline at end of file
